/// <reference types="webpack-env" />
/// <reference types="node" />
import { PropType, ComponentPublicInstance, VNode } from 'vue';
export type FavicoType = ((...args: unknown[]) => VNode) | ((...args: unknown[]) => string) | NodeRequire | string;
export interface Tab {
    /** 显示名称 */
    label: string;
    /** 唯一 key */
    key: string;
    favico?: FavicoType;
    /**
     * 是否可关闭
     */
    closable?: boolean;
    /**
     * 是否可被交换
     */
    swappable?: boolean;
    /**
     * 是否可拖拽
     */
    dragable?: boolean;
    $el?: HTMLElement;
    _instance?: any;
    _x?: number;
}
export interface Refs {
    [key: string]: Element | null;
}
declare const _default: import("vue").DefineComponent<{
    modelValue: {
        type: (StringConstructor | NumberConstructor)[];
        default: string;
    };
    tabs: {
        type: PropType<Tab[]>;
        default: () => never[];
    };
    /**
     * 当宽度小于设置的值时，会自动隐藏关闭按钮
     */
    autoHiddenCloseIconWidth: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * tab 的最小宽度
     */
    minWidth: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * tab 的最大宽度
     */
    maxWidth: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * 两个相邻的 tab 的空隙大小
     */
    gap: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * 关闭事件
     */
    onClose: {
        type: FunctionConstructor;
    };
    /**
     * 新 tab 追加时，是否追加到当前 tab 之后
     */
    insertToAfter: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 鼠标按下时，是否自动将命中的 tab 设置为激活状态
     */
    isMousedownActive: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 自定义渲染 label
     */
    renderLabel: {
        type: FunctionConstructor;
    };
}, {
    setTabRef: (el: Element | ComponentPublicInstance | null, tab: Tab) => void;
    setContentRef: (el: Element | ComponentPublicInstance | null) => void;
    setAfterRef: (el: Element | ComponentPublicInstance | null) => void;
    tabWidth: import("vue").Ref<number>;
    handleDelete: (tab: Tab, i: number) => false | undefined;
    handleContextMenu: (e: Event, tab: Tab, i: number) => void;
    showTabCloseIcon: (tab: Tab) => boolean;
    renderLabelText: (tab: Tab) => any;
    handleNativeClick: (e: Event, tab: Tab, i: number) => void;
    doLayout: () => void;
    addTab: (...newTabs: Array<Tab>) => void;
    removeTab: (tabKey: string | number) => void;
}, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, ("click" | "update:modelValue" | "remove" | "dragstart" | "dragging" | "dragend" | "swap" | "contextmenu")[], "click" | "update:modelValue" | "remove" | "dragstart" | "dragging" | "dragend" | "swap" | "contextmenu", import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<import("vue").ExtractPropTypes<{
    modelValue: {
        type: (StringConstructor | NumberConstructor)[];
        default: string;
    };
    tabs: {
        type: PropType<Tab[]>;
        default: () => never[];
    };
    /**
     * 当宽度小于设置的值时，会自动隐藏关闭按钮
     */
    autoHiddenCloseIconWidth: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * tab 的最小宽度
     */
    minWidth: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * tab 的最大宽度
     */
    maxWidth: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * 两个相邻的 tab 的空隙大小
     */
    gap: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * 关闭事件
     */
    onClose: {
        type: FunctionConstructor;
    };
    /**
     * 新 tab 追加时，是否追加到当前 tab 之后
     */
    insertToAfter: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 鼠标按下时，是否自动将命中的 tab 设置为激活状态
     */
    isMousedownActive: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * 自定义渲染 label
     */
    renderLabel: {
        type: FunctionConstructor;
    };
}>> & {
    onClick?: ((...args: any[]) => any) | undefined;
    "onUpdate:modelValue"?: ((...args: any[]) => any) | undefined;
    onRemove?: ((...args: any[]) => any) | undefined;
    onDragstart?: ((...args: any[]) => any) | undefined;
    onDragging?: ((...args: any[]) => any) | undefined;
    onDragend?: ((...args: any[]) => any) | undefined;
    onSwap?: ((...args: any[]) => any) | undefined;
    onContextmenu?: ((...args: any[]) => any) | undefined;
}, {
    modelValue: string | number;
    tabs: Tab[];
    autoHiddenCloseIconWidth: number;
    minWidth: number;
    maxWidth: number;
    gap: number;
    insertToAfter: boolean;
    isMousedownActive: boolean;
}>;
export default _default;
